@@ -1,8 +1,8 @@
 ;;; org-beamer.el --- Beamer-specific LaTeX export for org-mode
 ;;
-;; Copyright (C) 2007, 2008, 2009 Free Software Foundation, Inc.
+;; Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 ;;
-;; Version: 6.34c
+;; Version: 6.36c
 ;; Author: Carsten Dominik <carsten.dominik AT gmail DOT com>
 ;; Maintainer: Carsten Dominik <carsten.dominik AT gmail DOT com>
 ;; Keywords: org, wp, tex
@@ -124,7 +124,7 @@ For example
 Each entry has 4 elements:
 
 name    Name of the environment
-key     Selection key for `org-beamer-set-environment-tag'
+key     Selection key for `org-beamer-select-environment'
 open    The opening template for the environment, with the following excapes
         %a   the action/overlay specification
         %A   the default action/overlay specification
@@ -176,9 +176,13 @@ close   The closing string of the environment."
     (setq org-beamer-columns-open nil)
     (insert "\\end{columns}\n")))
 
-(defun org-beamer-set-environment-tag ()
-  "Set an environment tag, to determine the beamer environment to be used.
-This makes use of the fast tag selection interface."
+(defun org-beamer-select-environment ()
+  "Select the environment to be used by beamer for this entry.
+While this uses (for convenince) a tag selection interface, the result
+of this command will be that the BEAMER_env *property* of the entry is set.
+
+In addition to this, the command will also set a tag as a visual aid, but
+the tag does not have any semantic meaning."
   (interactive)
   (let* ((envs (append org-beamer-environments-extra
 		       org-beamer-environments-default))
@@ -252,7 +256,7 @@ in org-export-latex-classes."
 	  (and frame-level (= level frame-level)))
       ;; A frame
       (org-beamer-get-special props)
-      
+
       (setq in (org-fill-template
 		"\\begin{frame}%a%A%o%T%S%x"
 		(list (cons "a" (or action ""))
@@ -344,15 +348,16 @@ this function dynamically."
 
 (defvar org-beamer-mode-map (make-sparse-keymap)
   "The keymap for `org-beamer-mode'.")
-(define-key org-beamer-mode-map "\C-c\C-b" 'org-beamer-set-environment-tag)
+(define-key org-beamer-mode-map "\C-c\C-b" 'org-beamer-select-environment)
 
 (define-minor-mode org-beamer-mode
   "Special support for editing Org-mode files made to export to beamer."
   nil " Bm" nil)
-(font-lock-add-keywords
- 'org-mode
- '((":\\(B_[a-z]+\\|BMCOL\\):" 1 'org-beamer-tag prepend))
- 'prepent)
+(when (fboundp 'font-lock-add-keywords)
+  (font-lock-add-keywords
+   'org-mode
+   '((":\\(B_[a-z]+\\|BMCOL\\):" 1 'org-beamer-tag prepend))
+   'prepent))
 
 (defun org-beamer-place-default-actions-for-lists ()
   "Find default overlay specifications in items, and move them.
@@ -386,7 +391,7 @@ the value will be inserted right after the documentclass statement."
       (insert org-beamer-header-extra)
       (or (bolp) (insert "\n"))))))
 
-(defcustom org-beamer-fragile-re "^[ \t]*\\\\begin{verbatim}"
+(defcustom org-beamer-fragile-re "^[ \t]*\\\\begin{\\(verbatim\\|lstlisting\\)}"
   "If this regexp matches in a frame, the frame is marked as fragile."
   :group 'org-beamer
   :type 'regexp)
@@ -494,7 +499,21 @@ This funcion will run in the final LaTeX document."
 	      (setq opts (org-split-string opts ","))
 	      (add-to-list 'opts "fragile")
 	      (insert "[" (mapconcat 'identity opts ",") "]"))))))))
-  
+
+(defcustom org-beamer-outline-frame-title "Outline"
+  "Default title of a frame containing an outline."
+  :group 'org-beamer
+  :type '(string :tag "Outline frame title")
+)
+
+(defcustom org-beamer-outline-frame-options nil
+  "Outline frame options appended after \\begin{frame}.  You might
+want to put e.g. [allowframebreaks=0.9] here.  Remember to include
+square brackets."
+  :group 'org-beamer
+  :type '(string :tag "Outline frame options")
+)
+
 (defun org-beamer-fix-toc ()
   "Fix the table of contents by removing the vspace line."
   (when org-beamer-export-is-beamer-p
@@ -503,7 +522,10 @@ This funcion will run in the final LaTeX document."
       (when (re-search-forward "\\(\\\\setcounter{tocdepth.*\n\\\\tableofcontents.*\n\\)\\(\\\\vspace\\*.*\\)"
 			       nil t)
 	(replace-match
-	 "\\\\begin{frame}\n\\\\frametitle{Outline}\n\\1\\\\end{frame}"
+	 (concat "\\\\begin{frame}" org-beamer-outline-frame-options
+		 "\n\\\\frametitle{"
+		 org-beamer-outline-frame-title
+		 "}\n\\1\\\\end{frame}")
 	 t nil)))))
 
 (defun org-beamer-property-changed (property value)
