@@ -1,8 +1,28 @@
 ;;; org-ctags.el - Integrate Emacs "tags" facility with org mode.
 ;;;
+;; Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+
 ;;; Author: Paul Sexton <eeeickythump@gmail.com>
 ;;; Version: 1.0
-;;; Repository at http://bitbucket.org/eeeickythump/org-ctags/
+
+;; Keywords: org, wp
+;; Version: 6.36c
+;;
+;; This file is part of GNU Emacs.
+;;
+;; GNU Emacs is free software: you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
+
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
+
 ;;;
 ;;; Synopsis
 ;;; ========
@@ -131,7 +151,7 @@ tag destinations in org-mode files.
 Format is: /REGEXP/TAGNAME/FLAGS,TAGTYPE/
 See the ctags documentation for more information.")
 
-(defcustom org-ctags-path-to-ctags 
+(defcustom org-ctags-path-to-ctags
   (case system-type
     (windows-nt "ctags.exe")
     (darwin "ctags-exuberant")
@@ -141,14 +161,14 @@ See the ctags documentation for more information.")
   :type 'file)
 
 (defcustom org-ctags-open-link-functions
-  '(org-ctags-find-tag 
+  '(org-ctags-find-tag
     org-ctags-ask-rebuild-tags-file-then-find-tag
     org-ctags-ask-append-topic)
   "List of functions to be prepended to ORG-OPEN-LINK-FUNCTIONS when
 ORG-CTAGS is active."
   :group 'org-ctags
   :type 'hook
-  :options '(org-ctags-find-tag 
+  :options '(org-ctags-find-tag
              org-ctags-ask-rebuild-tags-file-then-find-tag
              org-ctags-rebuild-tags-file-then-find-tag
              org-ctags-ask-append-topic
@@ -194,9 +214,9 @@ The following patterns are replaced in the string:
 (defun org-ctags-enable ()
   (put 'org-mode 'find-tag-default-function 'org-ctags-find-tag-at-point)
   (setq org-ctags-enabled-p t)
-  (dolist (fn (reverse org-ctags-open-link-functions))
-    (add-hook 'org-open-link-functions fn)))
-  
+  (dolist (fn org-ctags-open-link-functions)
+    (add-hook 'org-open-link-functions fn t)))
+
 
 ;;; General utility functions. ===============================================
 ;;; These work outside org-ctags mode.
@@ -472,7 +492,7 @@ subdirectories contain large numbers of taggable files."
                      org-ctags-path-to-ctags
                      org-ctags-tag-regexp
                      (expand-file-name (concat dir-name "/TAGS"))
-                     (expand-file-name (concat dir-name "/")))))
+                     (expand-file-name (concat dir-name "/*")))))
       (cond
        ((eql 0 exitcode)
         (set (make-local-variable 'org-ctags-tag-list)
